==> haskell-xss-sanitize-0.3.5.7-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xss-sanitize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xss-sanitize
version: 0.3.5.7
id: xss-sanitize-0.3.5.7-JtwY0h7AXl57kDNiQenhrv
key: xss-sanitize-0.3.5.7-JtwY0h7AXl57kDNiQenhrv
license: BSD2
maintainer: Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://github.com/yesodweb/haskell-xss-sanitize
synopsis: sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details
category: Web
author: Greg Weber <greg@gregweber.info>
exposed: True
exposed-modules:
    Text.HTML.SanitizeXSS
hidden-modules: Text.HTML.SanitizeXSS.Css
abi: 4c307009b540ee022106921d8ebe7997
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/xss-sanitize-0.3.5.7
library-dirs: /usr/lib/ghc-8.0.2/site-local/xss-sanitize-0.3.5.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/xss-sanitize-0.3.5.7
hs-libraries: HSxss-sanitize-0.3.5.7-JtwY0h7AXl57kDNiQenhrv
depends:
    attoparsec-0.13.1.0-7xLJO1EwFQpJLBzOR8WqkC base-4.9.1.0
    containers-0.5.7.1 css-text-0.1.2.2-1Mci4JIOAs8K0BCVWHSNPo
    network-uri-2.6.1.0-GzRvaV3udR3JtWfa3CLYOw
    tagsoup-0.14.1-A8v7iyBjfz82GOKyhT5ypk
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    utf8-string-1.0.1.1-1DpjxLeTvGg7ttZZojxJR5
haddock-interfaces: /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock
haddock-html: /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xss-sanitize-0.3.5.7-25-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xss-sanitize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xss-sanitize
version: 0.3.5.7
id: xss-sanitize-0.3.5.7-2zR7fN8FZBAzRnRmSaQvx
key: xss-sanitize-0.3.5.7-2zR7fN8FZBAzRnRmSaQvx
license: BSD2
maintainer: Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://github.com/yesodweb/haskell-xss-sanitize
synopsis: sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details
category: Web
author: Greg Weber <greg@gregweber.info>
exposed: True
exposed-modules:
    Text.HTML.SanitizeXSS
hidden-modules: Text.HTML.SanitizeXSS.Css
abi: 2a643ff624b841c7bb9f24a9a56ac183
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/xss-sanitize-0.3.5.7
library-dirs: /usr/lib/ghc-8.0.2/site-local/xss-sanitize-0.3.5.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/xss-sanitize-0.3.5.7
hs-libraries: HSxss-sanitize-0.3.5.7-2zR7fN8FZBAzRnRmSaQvx
depends:
    attoparsec-0.13.2.0-JkqjYPxw7sG9Iq2J4E1Ndn base-4.9.1.0
    containers-0.5.7.1 css-text-0.1.2.2-6Q5LnJM55VkCU2asyTDbXf
    network-uri-2.6.1.0-GzRvaV3udR3JtWfa3CLYOw
    tagsoup-0.14.1-A8v7iyBjfz82GOKyhT5ypk
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    utf8-string-1.0.1.1-1DpjxLeTvGg7ttZZojxJR5
haddock-interfaces: /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock
haddock-html: /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
